From: { "order": 1, "ingredientId": 283702, "description": "", "notes": "", "quantity": [ { "servingSizeOrder": 1, "servingSizeQuantity": 1, "operator": "<", "quantity": 1, "unit": "Gram(s)", "dailyValueTargetGroup": [ { "name": "Adults and children 4 or more years of age", "operator": "=", "percent": 0, "footnote": null } ], "servingSizeUnit": "Gram(s)" } ], "nestedRows": [], "name": "Total Carbohydrates", "category": "sugar", "ingredientGroup": "Carbohydrate", "uniiCode": "0", "alternateNames": [], "forms": [] } { "name": "vitamin b", "measures": { "mass + mass equivalents": { "per package": { "grams": { "decimal string": "", "fraction string": "" }, "ounces": { } } }, "energy": { "per package": { "food calories": { "decimal string": "", "fraction string": "" } } } }, # # if IU # "biological activity": { "per package": { "IU": { "decimal string": "", "fraction string": "" } } } }, "unites": [] }